package com.six.dochub.soapclient;

import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.Bean;
import org.springframework.oxm.jaxb.Jaxb2Marshaller;

/**
 * Provides beans to configure the client.
 *
 * @author tsc and the ARIVA.DE REG III Team
 * @since 2020-08-26.
 */
@Slf4j
public class DocHubClientConfig {

    /**
     * Returns the JAXB2 marshaller.
     *
     * @return the marshaller
     */
    @Bean
    public Jaxb2Marshaller marshaller() {
        final Jaxb2Marshaller marshaller = new Jaxb2Marshaller();
        marshaller.setContextPath("com.six.dochub.soapclient.gen");
        return marshaller;
    }

    /**
     * Returns the DocHub client instance.
     *
     * @param marshaller the marshaller/unmarshaller to use
     * @return the client
     */
    @Bean
    public DocHubClient docHubClient(final Jaxb2Marshaller marshaller) {
        final DocHubClient client = new DocHubClient();
        client.setDefaultUri("https://test.six-dochub.com/api/soap/v3_1/");
        client.setMarshaller(marshaller);
        client.setUnmarshaller(marshaller);
        return client;
    }
}
